@@ -1,4 +1,5 @@
-# (c) 2009-2018 Martin Wendt and contributors; see WsgiDAV https://github.com/mar10/wsgidav
+# -*- coding: utf-8 -*-
+# (c) 2009-2021 Martin Wendt and contributors; see WsgiDAV https://github.com/mar10/wsgidav
 # Original PyFileServer (c) 2005 Ho Chun Wei.
 # Licensed under the MIT license:
 # http://www.opensource.org/licenses/mit-license.php
@@ -6,11 +7,12 @@
 Implements a DAVError class that is used to signal WebDAV and HTTP errors.
 """
 import datetime
-# import traceback
 
 from wsgidav import __version__, compat, xml_tools
 from wsgidav.xml_tools import etree
 
+# import traceback
+
 
 __docformat__ = "reStructuredText"
 
@@ -95,7 +97,7 @@ ERROR_DESCRIPTIONS = {
     HTTP_INTERNAL_ERROR: "500 Internal Server Error",
     HTTP_NOT_IMPLEMENTED: "501 Not Implemented",
     HTTP_BAD_GATEWAY: "502 Bad Gateway",
-    }
+}
 
 # ========================================================================
 # if ERROR_RESPONSES exists for an error code, a html output will be sent as response
@@ -108,8 +110,8 @@ ERROR_RESPONSES = {
     HTTP_NOT_FOUND: "The specified resource was not found",
     HTTP_FORBIDDEN: "Access denied to the specified resource",
     HTTP_INTERNAL_ERROR: "An internal server error occurred",
-    HTTP_NOT_IMPLEMENTED: "Not Implemented",
-    }
+    HTTP_NOT_IMPLEMENTED: "Not implemented",
+}
 
 
 # ========================================================================
@@ -128,34 +130,38 @@ class DAVErrorCondition(object):
     """May be embedded in :class:`DAVError` instances to store additional data.
 
     Args:
-        conditionCode (str): Should be PRECONDITION_CODE_...
+        condition_code (str): Should be PRECONDITION_CODE_...
     """
-    def __init__(self, conditionCode):
-        self.conditionCode = conditionCode
+
+    def __init__(self, condition_code):
+        self.condition_code = condition_code
         self.hrefs = []
 
     def __str__(self):
-        return "{}({})".format(self.conditionCode, self.hrefs)
+        return "{}({})".format(self.condition_code, self.hrefs)
 
     def add_href(self, href):
         assert href.startswith("/")
-        assert self.conditionCode in (PRECONDITION_CODE_LockConflict,
-                                      PRECONDITION_CODE_MissingLockToken)
+        assert self.condition_code in (
+            PRECONDITION_CODE_LockConflict,
+            PRECONDITION_CODE_MissingLockToken,
+        )
         if href not in self.hrefs:
             self.hrefs.append(href)
 
     def as_xml(self):
-        if self.conditionCode == PRECONDITION_CODE_MissingLockToken:
-            assert len(
-                self.hrefs) > 0, "lock-token-submitted requires at least one href"
-        errorEL = etree.Element("{DAV:}error")
-        condEL = etree.SubElement(errorEL, self.conditionCode)
+        if self.condition_code == PRECONDITION_CODE_MissingLockToken:
+            assert (
+                len(self.hrefs) > 0
+            ), "lock-token-submitted requires at least one href"
+        error_el = etree.Element("{DAV:}error")
+        cond_el = etree.SubElement(error_el, self.condition_code)
         for href in self.hrefs:
-            etree.SubElement(condEL, "{DAV:}href").text = href
-        return errorEL
+            etree.SubElement(cond_el, "{DAV:}href").text = href
+        return error_el
 
     def as_string(self):
-        return compat.to_native(xml_tools.xmlToBytes(self.as_xml(), True))
+        return compat.to_native(xml_tools.xml_to_bytes(self.as_xml(), True))
 
 
 # ========================================================================
@@ -165,84 +171,88 @@ class DAVErrorCondition(object):
 #     as in paste.httpexceptions.  This way you can catch just the exceptions
 #     you want (or you can catch an abstract superclass to get any of them)
 
+
 class DAVError(Exception):
     """General error class that is used to signal HTTP and WEBDAV errors."""
+
     # TODO: Ian Bicking proposed to add an additional 'comment' arg, but
-    #       couldn't we use the existing 'contextinfo'?
+    #       couldn't we use the existing 'context_info'?
     # @@: This should also take some message value, for a detailed error message.
     #     This would be helpful for debugging.
 
-    def __init__(self,
-                 statusCode,
-                 contextinfo=None,
-                 srcexception=None,
-                 errcondition=None):
+    def __init__(
+        self, status_code, context_info=None, src_exception=None, err_condition=None
+    ):
         # allow passing of Pre- and Postconditions, see
         # http://www.webdav.org/specs/rfc4918.html#precondition.postcondition.xml.elements
-        self.value = int(statusCode)
-        self.contextinfo = contextinfo
-        self.srcexception = srcexception
-        self.errcondition = errcondition
-        if compat.is_native(errcondition):
-            self.errcondition = DAVErrorCondition(errcondition)
-        assert self.errcondition is None or type(
-            self.errcondition) is DAVErrorCondition
+        self.value = int(status_code)
+        self.context_info = context_info
+        self.src_exception = src_exception
+        self.err_condition = err_condition
+        if compat.is_native(err_condition):
+            self.err_condition = DAVErrorCondition(err_condition)
+        assert (
+            self.err_condition is None or type(self.err_condition) is DAVErrorCondition
+        )
 
     def __repr__(self):
-        return "DAVError({})".format(self.getUserInfo())
+        return "DAVError({})".format(self.get_user_info())
 
     def __str__(self):  # Required for 2.4
         return self.__repr__()
 
-    def getUserInfo(self):
+    def get_user_info(self):
         """Return readable string."""
         if self.value in ERROR_DESCRIPTIONS:
             s = "{}".format(ERROR_DESCRIPTIONS[self.value])
         else:
             s = "{}".format(self.value)
 
-        if self.contextinfo:
-            s += ": {}".format(self.contextinfo)
+        if self.context_info:
+            s += ": {}".format(self.context_info)
         elif self.value in ERROR_RESPONSES:
             s += ": {}".format(ERROR_RESPONSES[self.value])
 
-        if self.srcexception:
-            s += "\n    Source exception: '{}'".format(self.srcexception)
+        if self.src_exception:
+            s += "\n    Source exception: '{}'".format(self.src_exception)
 
-        if self.errcondition:
-            s += "\n    Error condition: '{}'".format(self.errcondition)
+        if self.err_condition:
+            s += "\n    Error condition: '{}'".format(self.err_condition)
         return s
 
-    def getResponsePage(self):
-        """Return an tuple (content-type, response page)."""
+    def get_response_page(self):
+        """Return a tuple (content-type, response page)."""
         # If it has pre- or post-condition: return as XML response
-        if self.errcondition:
-            return ("application/xml",
-                    compat.to_bytes(self.errcondition.as_string()))
+        if self.err_condition:
+            return ("application/xml", compat.to_bytes(self.err_condition.as_string()))
 
         # Else return as HTML
-        status = getHttpStatusString(self)
+        status = get_http_status_string(self)
         html = []
         html.append(
             "<!DOCTYPE HTML PUBLIC '-//W3C//DTD HTML 4.01//EN' "
-            "'http://www.w3.org/TR/html4/strict.dtd'>")
+            "'http://www.w3.org/TR/html4/strict.dtd'>"
+        )
         html.append("<html><head>")
         html.append(
-            "  <meta http-equiv='Content-Type' content='text/html; charset=UTF-8'>")
+            "  <meta http-equiv='Content-Type' content='text/html; charset=UTF-8'>"
+        )
         html.append("  <title>{}</title>".format(status))
         html.append("</head><body>")
         html.append("  <h1>{}</h1>".format(status))
-        html.append("  <p>{}</p>".format(compat.html_escape(self.getUserInfo())))
+        html.append("  <p>{}</p>".format(compat.html_escape(self.get_user_info())))
         html.append("<hr/>")
-        html.append("<a href='https://github.com/mar10/wsgidav/'>WsgiDAV/{}</a> - {}"
-                    .format(__version__,
-                            compat.html_escape(str(datetime.datetime.now()), "utf-8")))
+        html.append(
+            "<a href='https://github.com/mar10/wsgidav/'>WsgiDAV/{}</a> - {}".format(
+                __version__, compat.html_escape(str(datetime.datetime.now()), "utf-8")
+            )
+        )
         html.append("</body></html>")
         html = "\n".join(html)
         return ("text/html", compat.to_bytes(html))
 
 
-def getHttpStatusCode(v):
+def get_http_status_code(v):
     """Return HTTP response code as integer, e.g. 204."""
     if hasattr(v, "value"):
         return int(v.value)  # v is a DAVError
@@ -250,30 +260,30 @@ def getHttpStatusCode(v):
         return int(v)
 
 
-def getHttpStatusString(v):
+def get_http_status_string(v):
     """Return HTTP response string, e.g. 204 -> ('204 No Content').
     The return string always includes descriptive text, to satisfy Apache mod_dav.
 
     `v`: status code or DAVError
     """
-    code = getHttpStatusCode(v)
+    code = get_http_status_code(v)
     try:
         return ERROR_DESCRIPTIONS[code]
     except KeyError:
         return "{} Status".format(code)
 
 
-def getResponsePage(v):
-    v = asDAVError(v)
-    return v.getResponsePage()
+def get_response_page(v):
+    v = as_DAVError(v)
+    return v.get_response_page()
 
 
-def asDAVError(e):
+def as_DAVError(e):
     """Convert any non-DAVError exception to HTTP_INTERNAL_ERROR."""
     if isinstance(e, DAVError):
         return e
     elif isinstance(e, Exception):
         # traceback.print_exc()
-        return DAVError(HTTP_INTERNAL_ERROR, srcexception=e)
+        return DAVError(HTTP_INTERNAL_ERROR, src_exception=e)
     else:
         return DAVError(HTTP_INTERNAL_ERROR, "{}".format(e))
