@@ -1,4 +1,5 @@
-# (c) 2009-2018 Martin Wendt and contributors; see WsgiDAV https://github.com/mar10/wsgidav
+# -*- coding: utf-8 -*-
+# (c) 2009-2021 Martin Wendt and contributors; see WsgiDAV https://github.com/mar10/wsgidav
 # Original PyFileServer (c) 2005 Ho Chun Wei.
 # Licensed under the MIT license:
 # http://www.opensource.org/licenses/mit-license.php
@@ -55,17 +56,16 @@ import threading
 
 from wsgidav import compat, util
 from wsgidav.middleware import BaseMiddleware
-from wsgidav.util import safeReEncode
+from wsgidav.util import safe_re_encode
 
 __docformat__ = "reStructuredText"
 
-_logger = util.getModuleLogger(__name__)
+_logger = util.get_module_logger(__name__)
 
 
 class WsgiDavDebugFilter(BaseMiddleware):
-
-    def __init__(self, application, config):
-        self._application = application
+    def __init__(self, wsgidav_app, next_app, config):
+        super(WsgiDavDebugFilter, self).__init__(wsgidav_app, next_app, config)
         self._config = config
         # self.out = sys.stdout
         self.passedLitmus = {}
@@ -95,14 +95,13 @@ class WsgiDavDebugFilter(BaseMiddleware):
         # Process URL commands
         if "dump_storage" in environ.get("QUERY_STRING", ""):
             dav = environ.get("wsgidav.provider")
-            if dav.lockManager:
-                dav.lockManager._dump()
-            if dav.propManager:
-                dav.propManager._dump()
+            if dav.lock_manager:
+                dav.lock_manager._dump()
+            if dav.prop_manager:
+                dav.prop_manager._dump()
 
         # Turn on max. debugging for selected litmus tests
-        litmusTag = environ.get(
-            "HTTP_X_LITMUS", environ.get("HTTP_X_LITMUS_SECOND"))
+        litmusTag = environ.get("HTTP_X_LITMUS", environ.get("HTTP_X_LITMUS_SECOND"))
         if litmusTag and verbose >= 3:
             _logger.info("----\nRunning litmus test '{}'...".format(litmusTag))
             for litmusSubstring in self.debug_litmus:
@@ -113,7 +112,10 @@ class WsgiDavDebugFilter(BaseMiddleware):
                     dumpResponse = True
                     break
             for litmusSubstring in self.break_after_litmus:
-                if litmusSubstring in self.passedLitmus and litmusSubstring not in litmusTag:
+                if (
+                    litmusSubstring in self.passedLitmus
+                    and litmusSubstring not in litmusTag
+                ):
                     _logger.info(" *** break after litmus {}".format(litmusTag))
                     sys.exit(-1)
                 if litmusSubstring in litmusTag:
@@ -139,8 +141,11 @@ class WsgiDavDebugFilter(BaseMiddleware):
             # _logger.info("<{}> --- {} Request ---".format(
             #         threading.currentThread().ident, method))
             for k, v in environ.items():
-                if k == k.upper():
-                    _logger.info("{:<20}: '{}'".format(k, safeReEncode(v, "utf8")))
+                try:
+                    v = safe_re_encode(v, "utf8")
+                except Exception:
+                    pass
+                _logger.info("{:<20}: '{!r}'".format(k, v))
             _logger.info("\n")
 
         # Intercept start_response
@@ -149,20 +154,27 @@ class WsgiDavDebugFilter(BaseMiddleware):
 
         nbytes = 0
         first_yield = True
-        app_iter = self._application(environ, sub_app_start_response)
+        app_iter = self.next_app(environ, sub_app_start_response)
 
         for v in app_iter:
             # Start response (the first time)
             if first_yield:
                 # Success!
-                start_response(sub_app_start_response.status,
-                               sub_app_start_response.response_headers,
-                               sub_app_start_response.exc_info)
+                start_response(
+                    sub_app_start_response.status,
+                    sub_app_start_response.response_headers,
+                    sub_app_start_response.exc_info,
+                )
 
             # Dump response headers
             if first_yield and dumpResponse:
-                _logger.info("<{}> ---{}  Response({}): ---".format(
-                    threading.currentThread().ident, method, sub_app_start_response.status))
+                _logger.info(
+                    "<{}> ---{}  Response({}): ---".format(
+                        threading.currentThread().ident,
+                        method,
+                        sub_app_start_response.status,
+                    )
+                )
                 headersdict = dict(sub_app_start_response.response_headers)
                 for envitem in headersdict.keys():
                     _logger.info("{}: {}".format(envitem, repr(headersdict[envitem])))
@@ -195,11 +207,16 @@ class WsgiDavDebugFilter(BaseMiddleware):
         # Start response (if it hasn't been done yet)
         if first_yield:
             # Success!
-            start_response(sub_app_start_response.status,
-                           sub_app_start_response.response_headers,
-                           sub_app_start_response.exc_info)
+            start_response(
+                sub_app_start_response.status,
+                sub_app_start_response.response_headers,
+                sub_app_start_response.exc_info,
+            )
 
         if dumpResponse:
-            _logger.info("<{}> --- End of {} Response ({:d} bytes) ---".format(
-                threading.currentThread().ident, method, nbytes))
+            _logger.info(
+                "<{}> --- End of {} Response ({:d} bytes) ---".format(
+                    threading.currentThread().ident, method, nbytes
+                )
+            )
         return
